==> zio-aws-mediastore_3-5.17.155.1-sources.jar: zio/aws/mediastore/model/Tag.scala <==
package zio.aws.mediastore.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.mediastore.model.primitives.{TagValue, TagKey}
import scala.jdk.CollectionConverters.*
final case class Tag(key: TagKey, value: Option[TagValue] = None) {
  def buildAwsValue(): software.amazon.awssdk.services.mediastore.model.Tag = {
    import Tag.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediastore.model.Tag
      .builder()
      .key(TagKey.unwrap(key): java.lang.String)
      .optionallyWith(
        value.map(value => TagValue.unwrap(value): java.lang.String)
      )(_.value)
      .build()
  }
  def asReadOnly: zio.aws.mediastore.model.Tag.ReadOnly =
    zio.aws.mediastore.model.Tag.wrap(buildAwsValue())
}
object Tag {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.mediastore.model.Tag] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediastore.model.Tag =
      zio.aws.mediastore.model.Tag(key, value.map(value => value))
    def key: TagKey
    def value: Option[TagValue]
    def getKey: ZIO[Any, Nothing, TagKey] = ZIO.succeed(key)
    def getValue: ZIO[Any, AwsError, TagValue] =
      AwsError.unwrapOptionField("value", value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediastore.model.Tag
  ) extends zio.aws.mediastore.model.Tag.ReadOnly {
    override val key: TagKey =
      zio.aws.mediastore.model.primitives.TagKey(impl.key())
    override val value: Option[TagValue] = scala
      .Option(impl.value())
      .map(value => zio.aws.mediastore.model.primitives.TagValue(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediastore.model.Tag
  ): zio.aws.mediastore.model.Tag.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediastore_3-5.17.217.1-sources.jar: zio/aws/mediastore/model/Tag.scala <==
package zio.aws.mediastore.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.mediastore.model.primitives.{TagValue, TagKey}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class Tag(key: TagKey, value: Optional[TagValue] = Optional.Absent) {
  def buildAwsValue(): software.amazon.awssdk.services.mediastore.model.Tag = {
    import Tag.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediastore.model.Tag
      .builder()
      .key(TagKey.unwrap(key): java.lang.String)
      .optionallyWith(
        value.map(value => TagValue.unwrap(value): java.lang.String)
      )(_.value)
      .build()
  }
  def asReadOnly: zio.aws.mediastore.model.Tag.ReadOnly =
    zio.aws.mediastore.model.Tag.wrap(buildAwsValue())
}
object Tag {
  private lazy val zioAwsBuilderHelper
      : BuilderHelper[software.amazon.awssdk.services.mediastore.model.Tag] =
    BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediastore.model.Tag =
      zio.aws.mediastore.model.Tag(key, value.map(value => value))
    def key: TagKey
    def value: Optional[TagValue]
    def getKey: ZIO[Any, Nothing, TagKey] = ZIO.succeed(key)
    def getValue: ZIO[Any, AwsError, TagValue] =
      AwsError.unwrapOptionField("value", value)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediastore.model.Tag
  ) extends zio.aws.mediastore.model.Tag.ReadOnly {
    override val key: TagKey =
      zio.aws.mediastore.model.primitives.TagKey(impl.key())
    override val value: Optional[TagValue] = zio.aws.core.internal
      .optionalFromNullable(impl.value())
      .map(value => zio.aws.mediastore.model.primitives.TagValue(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediastore.model.Tag
  ): zio.aws.mediastore.model.Tag.ReadOnly = new Wrapper(impl)
}
